==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/change/vo/ChangedesignestimatedetailVO.java <==
package com.ejianc.business.change.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.bedget.vo.DesignestimatedetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计概算变更子表
 * 
 * @author generator
 * 
 */
public class ChangedesignestimatedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long changeMid; // 变更主表id
    private java.lang.String sort; // 序号
    private java.lang.String name; // 名称
    private java.math.BigDecimal projectCost; // 项目造价
    private java.math.BigDecimal costPercent; // 造价占比
    private BigDecimal projectScale; // 工程规模
    private java.lang.String unitCost; // 单位造价
    private java.math.BigDecimal budgeTotal; // 预算书合计
    private java.math.BigDecimal laborCost; // 人工费
    private java.math.BigDecimal materialCost; // 材料费
    private java.math.BigDecimal machineryCost; // 机械费
    private java.math.BigDecimal businessManagerCost; // 企业管理费
    private java.math.BigDecimal profit; // 利润
    private java.math.BigDecimal measureItemsTotal; // 措施项目合计
    private java.math.BigDecimal safeCivilizedConstructionCost; // 安全文明施工费
    private java.math.BigDecimal transportConsumeCost; // 运输消纳费
    private java.math.BigDecimal scatteredExpenseseTotal; // 零星费用合计
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 规费合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String code; // 编码
    private java.lang.String tid;
    private java.lang.String tpid;
    private List<ChangedesignestimatedetailVO> children = new ArrayList<>();
    public List<ChangedesignestimatedetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ChangedesignestimatedetailVO> children) {
        this.children = children;
    }
    

    /**
     * 变更主表id
     */
    public java.lang.Long getChangeMid() {
        return changeMid;
    }

    /**
     * 变更主表id
     */
    public void setChangeMid(java.lang.Long changeMid) {
        this.changeMid = changeMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 造价占比
     */
    public java.math.BigDecimal getCostPercent() {
        return costPercent;
    }

    /**
     * 造价占比
     */
    public void setCostPercent(java.math.BigDecimal costPercent) {
        this.costPercent = costPercent;
    }
    /**
     * 工程规模
     */
    public BigDecimal getProjectScale() {
        return projectScale;
    }

    /**
     * 工程规模
     */
    public void setProjectScale(BigDecimal projectScale) {
        this.projectScale = projectScale;
    }
    /**
     * 单位造价
     */
    public java.lang.String getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价
     */
    public void setUnitCost(java.lang.String unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 预算书合计
     */
    public java.math.BigDecimal getBudgeTotal() {
        return budgeTotal;
    }

    /**
     * 预算书合计
     */
    public void setBudgeTotal(java.math.BigDecimal budgeTotal) {
        this.budgeTotal = budgeTotal;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborCost() {
        return laborCost;
    }

    /**
     * 人工费
     */
    public void setLaborCost(java.math.BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialCost() {
        return materialCost;
    }

    /**
     * 材料费
     */
    public void setMaterialCost(java.math.BigDecimal materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMachineryCost() {
        return machineryCost;
    }

    /**
     * 机械费
     */
    public void setMachineryCost(java.math.BigDecimal machineryCost) {
        this.machineryCost = machineryCost;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getBusinessManagerCost() {
        return businessManagerCost;
    }

    /**
     * 企业管理费
     */
    public void setBusinessManagerCost(java.math.BigDecimal businessManagerCost) {
        this.businessManagerCost = businessManagerCost;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasureItemsTotal() {
        return measureItemsTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasureItemsTotal(java.math.BigDecimal measureItemsTotal) {
        this.measureItemsTotal = measureItemsTotal;
    }
    /**
     * 安全文明施工费
     */
    public java.math.BigDecimal getSafeCivilizedConstructionCost() {
        return safeCivilizedConstructionCost;
    }

    /**
     * 安全文明施工费
     */
    public void setSafeCivilizedConstructionCost(java.math.BigDecimal safeCivilizedConstructionCost) {
        this.safeCivilizedConstructionCost = safeCivilizedConstructionCost;
    }
    /**
     * 运输消纳费
     */
    public java.math.BigDecimal getTransportConsumeCost() {
        return transportConsumeCost;
    }

    /**
     * 运输消纳费
     */
    public void setTransportConsumeCost(java.math.BigDecimal transportConsumeCost) {
        this.transportConsumeCost = transportConsumeCost;
    }
    /**
     * 零星费用合计
     */
    public java.math.BigDecimal getScatteredExpenseseTotal() {
        return scatteredExpenseseTotal;
    }

    /**
     * 零星费用合计
     */
    public void setScatteredExpenseseTotal(java.math.BigDecimal scatteredExpenseseTotal) {
        this.scatteredExpenseseTotal = scatteredExpenseseTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 规费合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/change/vo/ChangedesignestimatedetailVO.java <==
package com.ejianc.business.change.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.bedget.vo.DesignestimatedetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计概算变更子表
 * 
 * @author generator
 * 
 */
public class ChangedesignestimatedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long changeMid; // 变更主表id
    private java.lang.Long originalId; // 原始单据id（限额设计子表）
    private java.lang.String sort; // 序号
    private java.lang.String name; // 名称
    private java.math.BigDecimal projectCost; // 项目造价
    private java.math.BigDecimal costPercent; // 造价占比
    private BigDecimal projectScale; // 工程规模
    private java.lang.String unitCost; // 单位造价
    private java.math.BigDecimal budgeTotal; // 预算书合计
    private java.math.BigDecimal laborCost; // 人工费
    private java.math.BigDecimal materialCost; // 材料费
    private java.math.BigDecimal machineryCost; // 机械费
    private java.math.BigDecimal businessManagerCost; // 企业管理费
    private java.math.BigDecimal profit; // 利润
    private java.math.BigDecimal measureItemsTotal; // 措施项目合计
    private java.math.BigDecimal safeCivilizedConstructionCost; // 安全文明施工费
    private java.math.BigDecimal transportConsumeCost; // 运输消纳费
    private java.math.BigDecimal scatteredExpenseseTotal; // 零星费用合计
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 规费合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String code; // 编码
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String sonItemCode; // 子目编码
    private java.lang.String sonItemName; // 子目名称
    private String innercode; // 内码
    private String errorMsg; // 导入错误信息

    private List<ChangedesignestimatedetailVO> children = new ArrayList<>();
    public List<ChangedesignestimatedetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ChangedesignestimatedetailVO> children) {
        this.children = children;
    }
    

    /**
     * 变更主表id
     */
    public java.lang.Long getChangeMid() {
        return changeMid;
    }

    /**
     * 变更主表id
     */
    public void setChangeMid(java.lang.Long changeMid) {
        this.changeMid = changeMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 造价占比
     */
    public java.math.BigDecimal getCostPercent() {
        return costPercent;
    }

    /**
     * 造价占比
     */
    public void setCostPercent(java.math.BigDecimal costPercent) {
        this.costPercent = costPercent;
    }
    /**
     * 工程规模
     */
    public BigDecimal getProjectScale() {
        return projectScale;
    }

    /**
     * 工程规模
     */
    public void setProjectScale(BigDecimal projectScale) {
        this.projectScale = projectScale;
    }
    /**
     * 单位造价
     */
    public java.lang.String getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价
     */
    public void setUnitCost(java.lang.String unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 预算书合计
     */
    public java.math.BigDecimal getBudgeTotal() {
        return budgeTotal;
    }

    /**
     * 预算书合计
     */
    public void setBudgeTotal(java.math.BigDecimal budgeTotal) {
        this.budgeTotal = budgeTotal;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborCost() {
        return laborCost;
    }

    /**
     * 人工费
     */
    public void setLaborCost(java.math.BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialCost() {
        return materialCost;
    }

    /**
     * 材料费
     */
    public void setMaterialCost(java.math.BigDecimal materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMachineryCost() {
        return machineryCost;
    }

    /**
     * 机械费
     */
    public void setMachineryCost(java.math.BigDecimal machineryCost) {
        this.machineryCost = machineryCost;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getBusinessManagerCost() {
        return businessManagerCost;
    }

    /**
     * 企业管理费
     */
    public void setBusinessManagerCost(java.math.BigDecimal businessManagerCost) {
        this.businessManagerCost = businessManagerCost;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasureItemsTotal() {
        return measureItemsTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasureItemsTotal(java.math.BigDecimal measureItemsTotal) {
        this.measureItemsTotal = measureItemsTotal;
    }
    /**
     * 安全文明施工费
     */
    public java.math.BigDecimal getSafeCivilizedConstructionCost() {
        return safeCivilizedConstructionCost;
    }

    /**
     * 安全文明施工费
     */
    public void setSafeCivilizedConstructionCost(java.math.BigDecimal safeCivilizedConstructionCost) {
        this.safeCivilizedConstructionCost = safeCivilizedConstructionCost;
    }
    /**
     * 运输消纳费
     */
    public java.math.BigDecimal getTransportConsumeCost() {
        return transportConsumeCost;
    }

    /**
     * 运输消纳费
     */
    public void setTransportConsumeCost(java.math.BigDecimal transportConsumeCost) {
        this.transportConsumeCost = transportConsumeCost;
    }
    /**
     * 零星费用合计
     */
    public java.math.BigDecimal getScatteredExpenseseTotal() {
        return scatteredExpenseseTotal;
    }

    /**
     * 零星费用合计
     */
    public void setScatteredExpenseseTotal(java.math.BigDecimal scatteredExpenseseTotal) {
        this.scatteredExpenseseTotal = scatteredExpenseseTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 规费合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getSonItemCode() {
        return sonItemCode;
    }

    public void setSonItemCode(String sonItemCode) {
        this.sonItemCode = sonItemCode;
    }

    public String getSonItemName() {
        return sonItemName;
    }

    public void setSonItemName(String sonItemName) {
        this.sonItemName = sonItemName;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}
